pub struct DependencyConstraintRange {
pub lower: Option<DependencyVersionBound>,
pub upper: Option<DependencyVersionBound>,
}Expand description
What: Store the deterministic intersection of dependency version requirements.
Inputs:
- Zero or more
=,>,>=,<, or<=requirements for one resolved package.
Output:
- Exposes the most restrictive compatible lower and upper bounds.
Details:
- Equal requirements are represented by equal inclusive lower and upper bounds. An absent bound means no requirement on that side of the interval.
Fields
lower: Option<DependencyVersionBound>Most restrictive compatible lower bound, if any.
upper: Option<DependencyVersionBound>Most restrictive compatible upper bound, if any.