Module install

Module install 

Install-related data types for package installation command building.

Structs

CommandSpec
What: A ready-to-run command as program plus argument vector.
InstallOptions
What: Options controlling install command flag construction.

Enums

AurHelper
What: AUR helper used to install AUR packages.
CascadeMode
What: Removal cascade level controlling which pacman remove flags are used.
PrivilegeTool
What: Privilege escalation tool used to run pacman as root.