Module news

Module news 

News-related data types for Arch Linux news and security advisories.

Structs

ArchNewsItem
What: A news item from the Arch Linux news RSS feed.
SecurityAdvisory
What: A security advisory from security.archlinux.org.

Enums

AdvisorySeverity
What: Severity level of a security advisory.