pub fn command_on_path(cmd: &str) -> boolExpand description
What: Determine whether a command is available on the Unix PATH.
Inputs:
cmd: Program basename or path containing a path separator.
Output:
truewhen an executable file is found with the executable bit set.
Details:
- Honours Unix permission bits so a non-executable file on
PATHis not treated as a tool. - Ported from Pacsea’s
install/utils.rs.