Index-related data types for official repository package operations.
Structs
- Index
Query Result - What: Search result with optional fuzzy matching score.
- Mirror
Discovery Limits - What: Hold explicit bounds for caller-client mirror-status discovery.
- Mirror
Info - What: Represent one mirror-status row that can produce a pacman server line.
- Official
Index - What: Represent the full collection of official packages maintained in memory.
- Official
Package - What: Capture the minimal metadata about an official package entry.
Enums
- Installed
Packages Mode - What: Filter mode for querying explicitly installed packages.