Install-related data types for package installation command building.
Structs
- Command
Spec - What: A ready-to-run command as program plus argument vector.
- Install
Options - What: Options controlling install command flag construction.
Enums
- AurHelper
- What: AUR helper used to install AUR packages.
- Cascade
Mode - What: Removal cascade level controlling which pacman remove flags are used.
- Privilege
Tool - What: Privilege escalation tool used to run pacman as root.