News-related data types for Arch Linux news and security advisories.
Structs
- Arch
News Item - What: A news item from the Arch Linux news RSS feed.
- Security
Advisory - What: A security advisory from security.archlinux.org.
Enums
- Advisory
Severity - What: Severity level of a security advisory.